#
# spec file for package konkretcmpi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# 1 for python3, 0 for python2
%if 0%{?suse_version} >= 1500
%define python3 1
%else
%define python3 0
%endif
%if %{python3}
%define pythonpackagename python3
%else
%define pythonpackagename python
%endif

Name:           konkretcmpi
%define         libname   lib%{name}
%define         libsoname %{libname}0
Version:        0.9.2
Release:        15.3
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
%if %{python3}
BuildRequires:  python3-devel
%else
BuildRequires:  python-devel
%endif
BuildRequires:  sblim-cmpi-devel
BuildRequires:  swig
URL:            https://github.com/rnovacek/konkretcmpi
# Increment the version every time the source code changes.
Summary:        A tool for developing CMPI providers in the C programming language
# This is necessary to build the RPM as a non-root user.
License:        MIT
Group:          Development/Libraries/C and C++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Source0:        https://github.com/rnovacek/konkretcmpi/archive/%{version}/konkretcmpi-%{version}.tar.gz
Source0:        konkretcmpi-%{version}.tar.gz

# PATCH-FIX-UPSTREAM
# Fix for cim-schema 2.40.0 compatiblity
# See https://github.com/rnovacek/konkretcmpi/issues/3
Patch1:         0001-Honor-that-string-properties-with-EmbeddedInstance-q.patch
# PATCH-FIX-UPSTREAM
Patch2:         0002-Don-t-optimize-out-module-registration.patch
# PATCH-FIX-UPSTREAM
Patch3:         0003-Fix-returning-instance-as-an-output-argument-from-me.patch
# PATCH-FIX-UPSTREAM
Patch4:         0004-Fix-missing-rpath.patch
# PATCH-FIX-UPSTREAM
Patch5:         0005-konkretreg-ignore-KONKRET_REGISTRATION-macro-in-libr.patch
# PATCH-FIX-UPSTREAM
# stolen from Fedora
Patch8:         konkretcmpi-0.9.2-fix-segfault-mofelement.patch

# PATCH-FIX-OPENSUSE, kkaempf@suse.de
# Adapt for older cmake versions
Patch6:         older-cmake.patch

# PATCH-FIX-OPENSUSE, SWIG/Python on SLE 11 and below needs -classic switch, kkaempf@suse.de
#   See http://stackoverflow.com/questions/14192288/how-to-make-multiple-properties-valid-to-one-file-by-set-source-files-properties
#   why set_source_files_properties cannot be used (recognizes string as single property)
# CMake on SLE10 defines PYTHON_INCLUDE_PATH, not PYTHON_INCLUDE_DIR, kkaempf@suse.de
Patch7:         sle10.patch

%description
An open-source tool for rapidly developing CMPI providers in the C
programming language. KonkretCMPI makes CMPI provider development
easier by generating type-safe concrete CIM interfaces from MOF
definitions and by providing default implementations for many of the
provider operations.

%package -n %{libsoname}
Summary:        Shared library of konkretcmpi
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{libsoname}
This package contains the shared libkonkretcmpi library.

%package devel
Summary:        Development files for konkretcmpi
Group:          Development/Libraries/C and C++
Requires:       cim-schema >= 2.17
Requires:       cmake
Requires:       sblim-cmpi-devel

%description devel
An open-source tool for rapidly developing CMPI providers in the C
programming language. KonkretCMPI makes CMPI provider development
easier by generating type-safe concrete CIM interfaces from MOF
definitions and by providing default implementations for many of the
provider operations.

%package %{pythonpackagename}
Summary:        Python bindings for konkretcmpi
Group:          Development/Libraries/Python
%if 0%{?suse_version}
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%if %{python3}
%{!?py3_requires: %define py3_requires Requires: python3}
%{py3_requires}
%else
%{!?py_requires: %define py_requires Requires: python}
%{py_requires}
%endif
%else
Requires:       python2
%endif

%description %{pythonpackagename}
This package contains python binding for konkretcmpi.

%prep
# Untar the sources.
%setup -n konkretcmpi-%{version}
%if 0%{?suse_version} > 0
%if 0%{?suse_version} < 1320
%patch -P 6 -p1
%if 0%{?suse_version} < 1020
%patch -P 7 -p1
%endif
%endif
%endif
%if 0%{?rhel_version} > 0 && 0%{?rhel_version} < 700
%patch -P 6 -p1
%endif
%if 0%{?centos_version} > 0 && 0%{?centos_version} < 700
%patch -P 6 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 8 -p1

%build
rm -rf build
mkdir build
pushd build
# --with-schema=%{_datadir}/mof/cim-current
cmake \
  -DCMAKE_INSTALL_PREFIX=/usr \
  -DCMAKE_VERBOSE_MAKEFILE=TRUE \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_C_FLAGS_RELEASE:STRING="$RPM_OPT_FLAGS -fstack-protector -fno-delete-null-pointer-checks" \
  -DCMAKE_CXX_FLAGS_RELEASE:STRING="$RPM_OPT_FLAGS -fstack-protector -fno-delete-null-pointer-checks" \
  -DCMAKE_SKIP_RPATH=1 \
  -DPACKAGE_ARCHITECTURE=`uname -m` \
  -DEXPLICIT_TARGET="$EXPLICIT_TARGET" \
  -DLIB=%{_lib} \
  -DWITH_PYTHON=ON \
  ..
popd
make %{?_smp_mflags} -C build

%install
make DESTDIR=$RPM_BUILD_ROOT install/fast -C build
# Don't package .la object
rm -rf $RPM_BUILD_ROOT/usr/lib*/libkonkret.la

%clean
%{__rm} -rf $RPM_BUILD_ROOT

%post -n %{libsoname} -p /sbin/ldconfig

%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%defattr(-,root,root)
%{_libdir}/libkonkret.so.*
%{_libdir}/libkonkretmof.so.*
%doc README
%license COPYING

%files devel
%defattr(-,root,root)
%dir %{_includedir}/konkret
%{_includedir}/konkret/*.h
%{_libdir}/libkonkret.so
%{_libdir}/libkonkretmof.so
%{_bindir}/konkret
%{_bindir}/konkretreg
%{_datadir}/cmake/Modules/*

%files %{pythonpackagename}
%defattr(-,root,root)
%{python_sitearch}/*.so
%if 0%{?suse_version} > 0 && 0%{?suse_version} < 1020
%{python_sitelib}/*.py*
%else
%if %{python3}
%{python_sitearch}/*.py*
%else
%{python2_sitearch}/*.py*
%endif
%endif

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Feb 19 2023 Klaus Kämpf <kkaempf@suse.com>
- Fix build for 15.4, define py3_requires in .spec
* Fri May  1 2020 Klaus Kämpf <kkaempf@suse.com>
- build -python3 subpackage for openSUSE Leap 15 and later.
* Tue Jul 19 2016 mvetter@suse.com
- boo#985179 openlmi-providers fails to build
- boo#985247 openlmi-networking fails to build
- Fix build with gcc6.
  openlmi-providers uses konkretcmpi. If both are build with gcc6
  konkretcmpi segfaulted.
- Add konkretcmpi-0.9.2-fix-segfault-mofelement.patch
- Add -fno-delete-null-pointer-checks to CXXFlags and CFLags
* Fri Mar 18 2016 kkaempf@suse.com
- sync patches with upstream
  * rename
  0001-konkretreg-ignore-KONKRET_REGISTRATION-macro-in-libr.patch
  to 0005-konkretreg-ignore-KONKRET_REGISTRATION-macro-in-libr.patch
  konkretcmpi-0.9.2-fix-returning-instance-from-method.patch
  to 0003-Fix-returning-instance-as-an-output-argument-from-me.patch
  * add
  0002-Don-t-optimize-out-module-registration.patch
  0004-Fix-missing-rpath.patch
* Tue Aug  4 2015 kkaempf@suse.com
- add 0001-konkretreg-ignore-KONKRET_REGISTRATION-macro-in-libr.patch
  On some systems the KONKRET_REGISTRATION macro definition gets
  compiled into the provider library and then konkretreg generates
  incorrect registration file. This commit adds a check for this
  case.
* Thu Mar 26 2015 kkaempf@suse.com
- back out konkretmof.so name fix
* Mon Feb  9 2015 kkaempf@suse.com
- add upstream patch
  konkretcmpi-0.9.2-fix-returning-instance-from-method.patch
- add older-cmake.patch to build with older cmake versions
- fix konkretmof.so name (Factory cmake bug)
- fix konkretcmpi-python file path
- apply sle10.patch on SLE10 only
* Mon Feb  2 2015 kkaempf@suse.com
- fix rhel6 build
* Mon Apr 28 2014 kkaempf@suse.com
- Honor the fact that string properties with EmbeddedInstance
  qualifier are handled as instance properties.
  Fixes compatibility issue with cim-schema 2.40.0
  Add 0001-Honor-that-string-properties-with-EmbeddedInstance-q.patch
* Wed Apr 23 2014 kkaempf@suse.com
- Fix devel dependencies (cmake, sblim-cmpi-devel, cim-schema)
- Drop cim-server from requires.
* Wed Apr 23 2014 kkaempf@suse.com
- Follow shared library policy
  rename 'konkretcmpi' to 'libkonkretcmpi0'
* Mon Feb 10 2014 pwieczorkiewicz@suse.com
- Add '%%doc README NEWS COPYING' directive to the spec file
- Needed in SLE12 due to openlmi-providers dependency (fate#316180)
* Fri Jan 17 2014 kkaempf@suse.com
- Fix python install pathes (esp. fixes SLE10 build)
  swig-classic.patch renamed to sle10.patch
* Thu Oct 17 2013 kkaempf@suse.com
- Update to 0.9.2
  * Modifiable templates for method stubs.
  * Stub substitutions for method name, method type.
  * Generated code for method input arguments name and type.
  * Also generated code for output arguments.
  * Bugfix possible integer overflow.
  * Name collision avoidance for status variable in generated
  * Modifiable template for enumeration stub.
  * Plenty of bugfixes not announced in silent 0.9.1 release.
* Thu Aug  1 2013 kkaempf@suse.com
- Update to 0.9.1
  * Add support for embedded instances
  * Support varlist in KReturn2
  * Fix return type for generated indication functions
  * Enable direct calls
  * Fix method arguments that are both input and output
* Fri Jul 26 2013 kkaempf@suse.com
- Fix build for SLE11 (old swig, old cmake)
  Add swig-classic.patch
* Thu Jul 11 2013 kkaempf@suse.com
- fix libkonkretmof so symlinks
  add fix-libkonkretmof-so-symlinks.patch
* Wed Jun 26 2013 kkaempf@suse.com
- update to 'proxy' branch (0.9.0_35_g9729565)
- drop all patches, merged upstream
* Tue May 21 2013 kkaempf@suse.com
- Fix return type for generated indication functions
  (konkretcmpi-0.9.0-fix-indication-return-type.patch)
* Thu May  2 2013 kkaempf@suse.com
- Enable using direct calls in KDefaultGetInstance
  (enable-direct-call.patch)
- Fix method arguments that are both input and output
  (konkretcmpi-0.9.0-fix-inputoutput-method-arguments.patch)
- Create -python subpackage (konkretcmpi python bindings)
* Mon Mar 11 2013 kkaempf@suse.com
- Split off -devel subpackage
* Mon Mar 11 2013 kkaempf@suse.com
- Update to 0.9.0
  * Use CMake as buildsystem (added FindCMPI.cmake and
    FindKonkretCMPI.cmake modules)
  * Python bindings for the MOF parser
  * Fixed using experimental schema
  * Assertion crash fixed
  * Add missing headers
  * Many other minor bugs fixed
* Sat Mar 17 2012 dimstar@opensuse.org
- Add konkretcmpi-gcc47.patch: Fix build with gcc 4.7.
* Mon Aug  2 2010 kkaempf@novell.com
- Update to version 0.8.7
  Worked around bugs in certain CMPI brokers.
* Mon Aug 25 2008 npaxton@novell.com
- Update to latest version (0.8.6) of code
  - Converted KonkretCMPI to use GNU autotools.
  - Bug fixes and minor enhancements
* Thu Jul 10 2008 npaxton@novell.com
- added sblim-cmpi-devel to BuildRequires
* Wed Jul  9 2008 npaxton@novell.com
- cleanup spec file, add dir ownership, remove erroneous comments
- update to version 0.8.1 which includes upgrade to autotools
* Mon Jul  7 2008 npaxton@novell.com
- Initial version
